==> billogram-foundation-2.2.1.tgz: package/modules/components/button/ButtonContent.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import purebem from 'purebem';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const ButtonContent = React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            icon: PropTypes.string
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null
            };
        },

        renderChildren() {
            if (this.props.children === null) {
                return null;
            }

            return (
                <span className={ block('content-children') }>
                    { this.props.children }
                </span>
            );
        },

        renderIcon() {
            if (this.props.icon === null) {
                return null;
            }

            return (
                <i className={ purebem.many(block('content-icon'), `bi-${this.props.icon}`) } />
            );
        },

        render() {
            return (
                <div className={ block('content') }>
                    { this.renderIcon() }
                    { this.renderChildren() }
                </div>
            );
        }

    });

    return ButtonContent;

};

==> billogram-foundation-2.3.8.tgz: package/modules/components/button/ButtonContent.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import purebem from 'purebem';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const ButtonContent = React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            icon: PropTypes.oneOf([
                PropTypes.string,
                PropTypes.shape({
                    name: PropTypes.string.isRequired,
                    direction: PropTypes.oneOf(['left', 'right'])
                })
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null
            };
        },

        renderChildren() {
            if (this.props.children === null) {
                return null;
            }

            return (
                <span className={ block('content-children') }>
                    { this.props.children }
                </span>
            );
        },

        renderIcon() {
            if (this.props.icon === null) {
                return null;
            }

            const icon = typeof this.props.icon === 'string' ? this.props.icon : this.props.icon.name;
            return (
                <i className={ purebem.many(block('content-icon'), `bi-${icon}`) } />
            );
        },

        render() {
            return (
                <div className={ block('content') }>
                    { this.renderIcon() }
                    { this.renderChildren() }
                </div>
            );
        }

    });

    return ButtonContent;

};
